/* SLV2
 * Copyright (C) 2007 Dave Robillard <http://drobilla.net>
 *  
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#ifndef __SLV2_H__
#define __SLV2_H__

#ifdef __cplusplus
extern "C" {
#endif

#include "slv2/plugin.h"
#include "slv2/pluginclass.h"
#include "slv2/plugininstance.h"
#include "slv2/plugins.h"
#include "slv2/pluginui.h"
#include "slv2/pluginuiinstance.h"
#include "slv2/pluginuis.h"
#include "slv2/port.h"
#include "slv2/types.h"
#include "slv2/util.h"
#include "slv2/value.h"
#include "slv2/values.h"
#include "slv2/scalepoint.h"
#include "slv2/scalepoints.h"
#include "slv2/world.h"

#ifdef __cplusplus
} /* extern "C" */
#endif

#endif /* __SLV2_H__ */
